---
name: Docs
about: Documentation creation or corrections
title: ''
labels: ''
assignees: ''

---

**Description**

Brief description of documentation edit/creation requirement for https://luteorg.github.io/lute-manual/.

**For broken/incorrect documentation:**

* specify page in https://luteorg.github.io/lute-manual/, section, and link
* Take a first shot at correcting the issue.  I'll edit it for tone/consistency.

**For new documentation:**

* Include details about what you think is needed, e.g. your system setup etc.
* Take a first shot at correcting the issue.  I'll edit it for tone/consistency.
* Specify where you think it should go
